<?php
	/**
	 * Plugin Name: EDD iDEAL Checkout Gateways
	 * Plugin URI: http://www.ideal-checkout.nl
	 * Description: Additional Gateways for EDD
	 * Author: iDEAL Checkout
	 * Author URI: http://www.ideal-checkout.nl
	 * Version: EDD 2.2.8+
	 */

	$sRootPath = dirname(__FILE__);

	while((strlen($sRootPath) > 2) && !is_dir($sRootPath . '/idealcheckout'))
	{
		$sRootPath = dirname($sRootPath);
	}

	if(!is_dir($sRootPath . '/idealcheckout'))
	{
		die('Cannot find /idealcheckout/ folder.<br>File: ' . __FILE__ . '<br>Line: ' . __LINE__);
	}

	// Allow displaying errors
	if(false)
	{
		@ini_set('display_errors', 1);
		@ini_set('display_startup_errors', 1);
		@error_reporting(E_ALL | E_STRICT);
	}


	require_once($sRootPath . '/idealcheckout/includes/library.php');

	/*  */

	// Registers gateways
	function ic_edd_register_idealcheckout_gateways($gateways)
	{

		if(!isset($gateways['idealcheckoutideal']))
		{
			$gateways['idealcheckoutauthorizedtransfer'] = array('admin_label' => 'iDEAL Checkout Eenmalige Machtiging / Incasso', 'checkout_label' => __('Eenmalige Machtiging / Incasso', 'ic_edd'));
			$gateways['idealcheckoutcreditcard'] = array('admin_label' => 'iDEAL Checkout Credit Card', 'checkout_label' => __('Credit Card', 'ic_edd'));
			$gateways['idealcheckoutdirectebanking'] = array('admin_label' => 'iDEAL Checkout Direct E-Banking', 'checkout_label' => __('Direct E-Banking', 'ic_edd'));
			$gateways['idealcheckoutideal'] = array('admin_label' => 'iDEAL Checkout iDEAL', 'checkout_label' => __('iDEAL', 'ic_edd'));
			$gateways['idealcheckoutmaestro'] = array('admin_label' => 'iDEAL Checkout Maestro', 'checkout_label' => __('Maestro', 'ic_edd'));
			$gateways['idealcheckoutmanualtransfer'] = array('admin_label' => 'iDEAL Checkout Handmatige overboeking', 'checkout_label' => __('Handmatige overboeking', 'ic_edd'));
			$gateways['idealcheckoutmastercard'] = array('admin_label' => 'iDEAL Checkout Mastercard', 'checkout_label' => __('Mastercard', 'ic_edd'));
			$gateways['idealcheckoutmistercash'] = array('admin_label' => 'iDEAL Checkout Mister Cash', 'checkout_label' => __('Mister Cash', 'ic_edd'));
			$gateways['idealcheckoutpaypal'] = array('admin_label' => 'iDEAL Checkout PayPal', 'checkout_label' => __('PayPal', 'ic_edd'));
			$gateways['idealcheckoutpaysafecard'] = array('admin_label' => 'iDEAL Checkout Paysafecard', 'checkout_label' => __('Paysafecard', 'ic_edd'));
			$gateways['idealcheckoutvisa'] = array('admin_label' => 'iDEAL Checkout Visa', 'checkout_label' => __('Visa', 'ic_edd'));
			$gateways['idealcheckoutvpay'] = array('admin_label' => 'iDEAL Checkout V PAY', 'checkout_label' => __('V PAY', 'ic_edd'));

			// idealcheckout_log('iDEAL Checkout gateways loaded for EasyDigitalDownloads.', __FILE__, __LINE__);
		}

		return $gateways;
	}
	add_filter('edd_payment_gateways', 'ic_edd_register_idealcheckout_gateways');


	function ic_edd_process_idealcheckout_return()
	{
		global $edd_options;

		if(isset($_GET['order_id'], $_GET['order_code']))
		{
			idealcheckout_log('iDEAL Checkout status update detected.', __FILE__, __LINE__);

			$aDatabaseSettings = idealcheckout_getDatabaseSettings();

			$sql = "SELECT * FROM `" . $aDatabaseSettings['prefix'] . "idealcheckout_transactions` WHERE (`order_id` = '" . idealcheckout_escapeSql($_GET['order_id']) . "') AND (`order_code` = '" . idealcheckout_escapeSql($_GET['order_code']) . "') LIMIT 1;";
			if($aRecord = idealcheckout_database_getRecord($sql))
			{
				$aOrderParams = idealcheckout_unserialize($aRecord['order_params']);

				if(strcasecmp($aRecord['transaction_status'], 'SUCCESS') === 0)
				{
					if(!empty($aOrderParams['payment_id']))
					{
						$iPaymentId = $aOrderParams['payment_id'];

						$sql = "SELECT `ID` FROM `" . $aDatabaseSettings['prefix'] . "posts` WHERE (`ID` = '" . idealcheckout_escapeSql($iPaymentId) . "') AND (`post_status` = 'publish') LIMIT 1;";

						if(!idealcheckout_database_isRecord($sql))
						{
							// once a transaction is successful, set the purchase to complete
							edd_update_payment_status($iPaymentId, 'complete');
							idealcheckout_log('EDD payment #' . $iPaymentId . ' set on "completed".', __FILE__, __LINE__);
						}

						// Empty cart
						edd_empty_cart();
						idealcheckout_log('EDD cart was flushed/cleared or whatever you want to call it.', __FILE__, __LINE__);

						// go to the success page
						edd_send_to_success_page();
					}
					else
					{
						idealcheckout_log('No payment_id found in column `order_params` in record #' . $aRecord['id'] . ' from table `#_idealcheckout`', __FILE__, __LINE__);
					}
				}
				elseif(in_array($aRecord['transaction_status'], array('FAILURE', 'CANCELLED')))
				{
					if(!empty($aOrderParams['payment_id']))
					{
						$iPaymentId = $aOrderParams['payment_id'];

						edd_update_payment_status($iPaymentId, 'failed');
						$sUrl = edd_get_checkout_uri();
						wp_redirect($sUrl);
					}
					else
					{
						idealcheckout_log('No payment_id found in column `order_params` in record #' . $aRecord['id'] . ' from table `#_idealcheckout`', __FILE__, __LINE__);
					}
				}
				else
				{
					idealcheckout_log('Cannot find a status for order_id #' . $_GET['order_id'] . ' and order_code #' . $_GET['order_code'] . '.', __FILE__, __LINE__);
				}
			}
			else
			{
				idealcheckout_log('No record found for order_id #' . $_GET['order_id'] . ' and order_code #' . $_GET['order_code'] . '.', __FILE__, __LINE__);
			}
		}
		else
		{
			idealcheckout_log('No order_id and order_code found in $_GET.', __FILE__, __LINE__);
		}
	}
	add_action('init', 'ic_edd_process_idealcheckout_return', 999);

	if(isset($_POST['payment-mode']))
	{
		$sSelectedGateway = $_POST['payment-mode'];

		if(strpos($sSelectedGateway, 'idealcheckout') !== false)
		{
			idealcheckout_loadGatewayFile($sSelectedGateway);
		}
	}
	else
	{
		function ic_edd_payment_gateway()
		{
			global $edd_options;

			if(function_exists('edd_get_chosen_gateway'))
			{
				$sSelectedGateway = edd_get_chosen_gateway();
			}

			idealcheckout_loadGatewayFile($sSelectedGateway);
		}
		add_action('init', 'ic_edd_payment_gateway');
	}

	function idealcheckout_loadGatewayFile($sGatewayName = null)
	{
		if(!empty($sGatewayName) && !function_exists('ic_edd_process_' . $sGatewayName . '_payment'))
		{
			$sEddIdealcheckoutGatewaysFolder = __DIR__;

			if(file_exists($sEddIdealcheckoutGatewaysFolder . '/' . $sGatewayName . '.php'))
			{
				require_once($sEddIdealcheckoutGatewaysFolder . '/' . $sGatewayName . '.php');
			}

			return true;
		}
		else
		{
			return false;
		}
	}

?>
